"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var console_1 = require("console");
var fs_1 = __importDefault(require("fs"));
var path_1 = __importDefault(require("path"));
var generate_1 = require("./generate");
var generate_docsify_1 = require("./generate_docsify");
var generate_gitbook_1 = require("./generate_gitbook");
var organize_1 = require("./organize");
var terminalConsole = new console_1.Console(process.stdout, process.stderr);
/**
 * Get all files in folder, recursively.
 * @param {string} folder folder path
 * @param {array} ignoreFilesList an array of files to be ignored
 */
function deepListFiles(folder, ignoreFilesList) {
    var files = [];
    var filesList = fs_1.default.readdirSync(folder);
    filesList.forEach(function (file) {
        if (ignoreFilesList.includes(file)) {
            return;
        }
        var stats = fs_1.default.lstatSync(path_1.default.join(folder, file));
        if (stats.isDirectory()) {
            var result = deepListFiles(path_1.default.join(folder, file), ignoreFilesList);
            result.forEach(function (r) { return files.push(r); });
            return;
        }
        if (path_1.default.extname(file) === '.sol') {
            files.push(path_1.default.join(folder, file));
        }
    });
    return files;
}
/**
 * Main method to be called. Will create the HTML using the other methods.
 * @param {string} outputType the output type of the given documentation
 * @param {string} ignoreFilesList an array of files to be ignored
 * @param {string} outputFolder directory to output the result, either pdf or html
 * @param {string} inputPath the path to file or folder to be analized
 */
function generate(outputType, ignoreFilesList, outputFolder, inputPath) {
    var stats;
    try {
        stats = fs_1.default.lstatSync(inputPath);
    }
    catch (e) {
        terminalConsole.log("The file you are looking for (" + inputPath + ") doesn't exist!");
        return 1;
    }
    var files = [];
    // verify if the input is a directory, file or array of files
    if (stats.isDirectory()) {
        files = deepListFiles(inputPath, ignoreFilesList);
    }
    else if (stats.isFile() && !ignoreFilesList.includes(inputPath)) {
        files.push(inputPath);
    }
    var prepared = [];
    files.forEach(function (file) { return prepared.push(organize_1.prepareForFile(file)); });
    var destinationDocsFolderPath = path_1.default.join(process.cwd(), outputFolder);
    if (!fs_1.default.existsSync(destinationDocsFolderPath)) {
        fs_1.default.mkdirSync(destinationDocsFolderPath, { recursive: true });
    }
    var generateClass = new generate_1.Generate(files, ignoreFilesList, inputPath, outputFolder);
    if (outputType === 'pdf') {
        generateClass.pdf();
    }
    else if (outputType === 'html') {
        generateClass.html();
    }
    else if (outputType === 'gitbook') {
        generate_gitbook_1.generateDocumentation(prepared, outputFolder);
    }
    else if (outputType === 'docsify') {
        generate_docsify_1.generateDocumentation(prepared, outputFolder);
    }
    else {
        terminalConsole.error('Invalid output type! Try --help for more info.');
        return 1;
    }
    return 0;
}
exports.generate = generate;
//# sourceMappingURL=index.js.map